/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Juha Ristolainen <juha.ristolainen@codemancers.fi>
 *              Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Nick Leppänen Larsson <frals@frals.se>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Popups 0.1 as Popups
import "../common/ClockUtils.js" as Utils


/*!
    \brief ClockPage is a page that lives inside the "Clock"-tab of the application
*/

Page {
    Component.onCompleted: {
        Utils.log("ClockPage loaded");
        currentTimeFormatted = Qt.formatTime(new Date());
        selectedLocation = "USER'S LOCATION TODO"

        // Obtaining the sunrise/sunset times as soon as clock page is loaded.
        clockFace.reloadSunRiseModel()
    }

    // Property to hold the formatted time string to show on the screen
    property string currentTimeFormatted

    // Property to hold the selected location to show time for
    // TODO: how to get user's set location?
    property string selectedLocation

    /*!
      \brief main Timer calls this on every 1000ms
      */
    function onTimerUpdate(now) {
        currentTimeFormatted = Qt.formatTime(now);

        // Update time
        clockFace.timeChanged(now)
    }

    Label {
        id: currentTimeLabel

        objectName: "currentTimeLabel"

        width: parent.width; height: parent.height / 4
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        fontSize: "x-large"

        text: currentTimeFormatted
    }

    AnalogClockFace {
        id: clockFace
        anchors.centerIn: parent
    }

    Label {
        id: locationLabel

        width: parent.width; height: parent.height / 4
        anchors.bottom: parent.bottom
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        fontSize: "large"

        text: selectedLocation
    }

    Component {
        id: locationDialogComponent

        Popups.Dialog {
            id: dialog
            title: "Location information"
            text: "Enter your latitude and longtitude"

            TextField {
                id: latitudeField
                width: parent.width/2
                placeholderText: 'latitude'
            }

            TextField {
                id: longitudeField
                width: parent.width/2
                placeholderText: 'longitude'
            }

            Button {
                id: goButton
                text: 'Ok'
                color: 'green'
                onClicked: {
                    clockFace.latitude = latitudeField.text
                    clockFace.longitude = longitudeField.text
                    PopupUtils.close(dialog)
                }
            }
        }
    }

    tools: ToolbarActions {
        Action {
            id: locationAction
            objectName: "changeSubredditAction"

            iconSource: Qt.resolvedUrl("../images/add_icon.png")
            text: i18n.tr("Add Location")

            onTriggered: {
                PopupUtils.open(locationDialogComponent, locationAction.itemHint)
            }
        }
    }


}
