/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Marco Biscaro <marcobiscaro2112@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "Constants.js" as Constants
import "ClockUtils.js" as Utils

Rectangle {
    id: clockMarker

    property int number
    property real radAngle: (number % 12 * 30) * Math.PI / 180
    property real distance: 0.45
    property real size: 1
    property bool textDisplay: false
    property alias textSize: markerText.font.pointSize
    property alias textColor: markerText.color

    width: units.gu(size); height: units.gu(size); z: 1
    radius: width / 2
    anchors.centerIn: parent
    color: textDisplay ? "transparent" : Constants.normalGrey
    antialiasing: true

    Text {
        id: markerText
        anchors.centerIn: parent
        visible: textDisplay ? true : false;
        font.pointSize: units.gu(1.4)
        color: Constants.darkGrey
        text: Utils.numberToLocaleString(number);
    }

    transform: Translate {
        x: parent.width * distance * Math.sin(radAngle)
        y: -parent.height * distance * Math.cos(radAngle)
    }

}
