/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Renato Araujo Oliveira Filho <renato.filho@canonical.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    id: animationContainer

    default property alias contents: container.children
    property alias state: container.state

    // Properties to set/get the state and yPosition of elements
    readonly property int swipeTolerance: 50;
    property real initYPos;
    property real finalYPos;

    clip: true;

    function swipeView() {
        container.state = (container.state == "DEFAULT") ? "SCROLLED" : "DEFAULT"
    }

    function changeView(initMousePos, finalMousePos) {
        if (finalMousePos > initMousePos + swipeTolerance && container.state == "SCROLLED") {
            container.state = "DEFAULT"
        }
        else if (finalMousePos < initMousePos - swipeTolerance && container.state == "DEFAULT"){
            container.state = "SCROLLED"
        }
        else {
            container.y = container.state == "DEFAULT" ? initYPos : finalYPos
        }
    }

    Item {
        id: container

        anchors { left: parent.left; right: parent.right; }
        height: childrenRect.height
        y: animationContainer.initYPos
        state: "DEFAULT"

        Behavior on y {
            id: containerYBehavior
            UbuntuNumberAnimation { duration: UbuntuAnimation.SlowDuration }
        }

        states:[
            State {
                name: "DEFAULT"
                PropertyChanges { target: container; y: initYPos }
            },
            State {
                name: "SCROLLED"
                PropertyChanges { target: container; y: finalYPos }
            }
        ]
    }

    MouseArea {
        id: swipeArea

        property int clickedMousePosition

        z: -1
        anchors.fill: parent

        onPressed: {
            containerYBehavior.enabled = false;
            clickedMousePosition = mouseY;
        }

        onReleased: {
            containerYBehavior.enabled = true;
            changeView(clickedMousePosition, mouseY)
        }

        onPositionChanged: {
            if (mouseY > clickedMousePosition && container.state == "SCROLLED") {
                container.y = (mouseY - clickedMousePosition) + finalYPos
            }
            else if (mouseY < clickedMousePosition && container.state == "DEFAULT") {
                container.y = initYPos - (clickedMousePosition - mouseY)
            }
        }
    }
}

