/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alessandro Pozzi <signor.hyde@gmail.com>
 *              Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../common/Constants.js" as Constants
import "../common"

// This component draws the stopwatch analog UI and defines different UI modes like normal and easteregg.
AnalogFaceBase {
    id: analogStopwatch

    property int decimalsTotal: 0;
    property int lastSecond: 0;

    property int hours: 0;
    property int minutes: 0;
    property int seconds: 0;
    property int decimals: 0;

    property int decimalgradient: decimalsTotal;
    property int minuteHandValue: minutes;
    property int secondHandValue: seconds;
    property real perRadius: 6;

    // Sets the location and visible (bool) values of the blip (small circle visible when the lap button is pressed)
    property alias blipLocation: blipFist.location;
    property alias blipVisible: blipFist.visible;

    // Retrieves the status of the stopwatch timer
    property bool timerStatus: stopwatchTimer.running

    onDecimalsTotalChanged: {
        decimals = decimalsTotal - lastSecond;
        if (decimals > 9) {
            var time = decimalsTotal
            time = Math.floor(time / 10)
            seconds = time % 60
            time = Math.floor(time / 60)
            minutes = time % 60
            hours = Math.floor(time / 60)

            lastSecond = decimalsTotal
        }
    }

    function reset() {
        decimalsTotal = lastSecond = decimals = seconds = minutes = hours = 0
    }

    function start() {
        stopwatchTimer.start()
    }

    function stop() {
        stopwatchTimer.stop()
    }

    // Inbuilt timer which runs every 100 microseconds
    Timer {
        id: stopwatchTimer

        interval: 100
        repeat: true
        onTriggered: decimalsTotal++;
    }

    // This component draws the small orange circle that is visible everytime the lap button is pressed.
    Blip {
        id: blipFist
    }
    
    // This component draws the trailing shadow of the second hand.
    HandGradient {
        id: gradientSecond
        rotationAngle: secondHandValue * perRadius
        decimalGradient: decimalgradient
    }    

    Repeater {
        id:stopwatchMarkers
        
        model: ["1", "2", "4", "5", "7", "8", "10", "11"]
        
        delegate: AnalogClockMarker {
            number: modelData
            size: 0.5
            color: Constants.pitchBlack
        }
    }

    Repeater {
        model: ["15", "30", "45", "60"]

        delegate: AnalogClockMarker {
            number: modelData
            textDisplay: true
        }
    }

    // Draws the second and minute hand.
    AnalogHand {
        id: secondHand
        
        rotationAngle: secondHandValue * perRadius
        widthhand: units.gu(0.5); heighthand: units.gu(17); heighttop: units.gu(5)
        colorhand: Constants.brightWhite
        colortop: Constants.ubuntuOrange
    }

    AnalogHand {
        id: minuteHand

        rotationAngle: minuteHandValue * 6
        widthhand: units.gu(0.5); heighthand: units.gu(6); heighttop: units.gu(0)
        z: circleMinutes.z + 1
        colorhand: Constants.pitchBlack
        colortop: Constants.ubuntuOrange
    }
    
    Rectangle {
        id: circleMinutes
        
        width: units.gu(15); height: units.gu(15)
        anchors.centerIn: parent
        color: Constants.normalGrey
        radius: width / 2
        z: parent.z + 1
        antialiasing: true
    }
}
