/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Renato Araujo Oliveira Filho <renato.filho@canonical.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1

UbuntuShape {
    id: animatedLabel

    property alias textColor: text0.color
    property alias fontSize: text0.fontSize
    property string text

    signal clicked(var mouse)

    // clip is necessary to clip the column element which is used to scroll animation
    clip: true
    width: units.gu(7); height: units.gu(7)
    color: Constants.brightWhite

    // Make sure that the inital text is displayed in the label
    Component.onCompleted: text0.text = animatedLabel.text

    Behavior on text {
        SequentialAnimation {
            // Update the text to the new value before start the animation
            PropertyAction {}

            ScriptAction {
                script: {
                    text1.text = animatedLabel.text
                }
            }

            PropertyAnimation {
                target: contents; property: "y"; to: - animatedLabel.height; duration: 750;
            }

            ScriptAction {
                script: {
                    text0.text = animatedLabel.text
                    contents.y = 0
                }
            }
        }
    }

    Column {
        id: contents

        x: 0
        height: childrenRect.height
        anchors {
            left: parent.left
            right: parent.right
        }

        Label {
            id: text0

            width: animatedLabel.width; height: animatedLabel.height
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            fontSize: "x-large"
        }

        Label {
            id: text1

            width: animatedLabel.width; height: animatedLabel.height
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: text0.color
            fontSize: text0.fontSize
        }
    }   

    MouseArea {
        anchors.fill: parent

        onClicked: animatedLabel.clicked(mouse)
    }
}
