/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Alessandro Pozzi <signor.hyde@gmail.com>
 */

import QtQuick 2.0
import QtGraphicalEffects 1.0
import "../common/Constants.js" as Constants

Item {
    id: handGradient

    property alias rotationAngle: handGradientRotation.angle
    property int decimalGradient;

    width: units.gu(34); height: units.gu(34)
    anchors.centerIn: parent
    antialiasing: true

    ConicalGradient {
        anchors.fill: parent
        source: Rectangle {
            width: units.gu(34); height: units.gu(34)
            radius: width / 2
            antialiasing: true
        }

        gradient: Gradient {
            GradientStop {
                position: {
                    if (decimalGradient == 0) {
                        0.9999;
                    } else if (decimalGradient > 0 && decimalGradient < 300) {
                        1 - (0.0016 * decimalGradient);
                    } else {
                        0.50;
                    }
                }
                color: Constants.brightWhite
            }
            GradientStop { position: 1.0; color: Constants.normalGrey }
        }
    }

    Rectangle {
        width: units.gu(24); height: units.gu(24)
        radius: width / 2
        anchors.centerIn: parent
        antialiasing: true
    }

    transform: Rotation {
        id: handGradientRotation

        origin { x: handGradient.width / 2; y: handGradient.height /2 }

        Behavior on angle {
            SpringAnimation { spring: 0.9; damping: 0.2; modulus: 360 }
        }
    }
}
