# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Renato Araujo Oliveira Filho <renato@canonical.com>


"""clock-app autopilot tests."""

import os.path
import os

from autopilot.introspection.qt import QtIntrospectionTestMixin
from autopilot.testcase import AutopilotTestCase

from clock_app.emulators.main_window import MainWindow

class ClockAppTestCase(AutopilotTestCase, QtIntrospectionTestMixin):

    """A common test case class that provides several useful methods for clock-app tests."""

    def setUp(self):
        super(ClockAppTestCase, self).setUp()

    def launch_app(self, movie_file=None):
        if movie_file == None:
            movie_file = ""
        # Lets assume we are installed system wide if this file is somewhere in /usr
        if os.path.realpath(__file__).startswith("/usr/"):
            self.launch_test_installed(movie_file)
        else:
            self.launch_test_local(movie_file)

    def launch_test_local(self, movie_file):
        self.app = self.launch_test_application(
                    "qmlscene",
                    "../../ubuntu-clock-app.qml"
                    )

    def launch_test_installed(self, movie_file):
        if self.running_on_device():
            self.app = self.launch_test_application(
               "ubuntu-clock-app",
               "--fullscreen "
               )
        else:
            self.app = self.launch_test_application(
               "ubuntu-clock-app.qml"
               )

    @staticmethod
    def running_on_device():
        return os.path.isfile('/system/usr/idc/autopilot-finger.idc')

    @property
    def main_window(self):
        return MainWindow(self.app)

