/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../common"
import "../common/Constants.js" as Constants

// Component which draws the analog timer face.
AnalogFaceBase {
    id: clockOuterCircle

    // Properties to store/set the time variables
    property int seconds: 0;
    property int minutes: 0;
    property int hours: 0;
    property int totalTime: 0;
    property int timerValue: 0;

    // Property to activate/deactivate the timer
    property bool timerOn: false;

    // Properties to get/set the timer hand properties
    property alias timerHandColor: timerHand.colortop;
    property alias timerHandRotation: timerHand.rotationAngle;

    // Properties to set/determine the input focus
    property bool secondsFlag
    property bool minutesFlag
    property bool hoursFlag
    property bool inProgressFlag

    onTotalTimeChanged: {
        if (totalTime < 0) {
            timerOn = false;
        }
        else {
            setTime(totalTime);
        }
    }

    // Timer function called by the main clock loop
    function onTimerUpdate () {
        if( timerOn ) {
            totalTime--;
            timerHand.rotationAngle = seconds * 6;
        }
    }

    // Function to calculate the hours, minutes and seconds from the total time
    function setTime ( sec ) {
        var time = sec
        seconds = time % 60
        time = Math.floor(time / 60)
        minutes = time % 60
        hours = Math.floor(time / 60)
    }

    // Function to disable timer and reset time
    function reset() {
        timerOn = false;
        hours = minutes = seconds = totalTime = timerValue = timerHand.rotationAngle = 0;
    }

    AnalogHand {
        id: timerHand
        
        widthhand: units.gu(2); heighthand: units.gu(16); heighttop: units.gu(5)
        rotationAngle: seconds * 6
        colorhand: Constants.brightWhite
        colortop: Constants.ubuntuOrange
    }
    
    Rectangle {
        id: secondsCircle
        
        width: units.gu(5); height: units.gu(5)
        radius: width / 2
        anchors.centerIn: parent
        color: Constants.brightWhite
        antialiasing: true
        z: parent.z + 100
    }

    Repeater {
        model: ["0", "15", "30", "45"]
        delegate: AnalogClockMarker {
            number: modelData
            distance: 0.60
            textDisplay: true
        }
    }
    
    Repeater {
        model: 12
        delegate: AnalogClockMarker {
            number: index
            size: 0.5
            distance: 0.55
            color: Constants.pitchBlack
        }
    }
    
    // Implements touch support
    MouseArea {
        id: timerbackmousearea
        
        property real truex: mouseX - clockOuterCircle.width/2
        property real truey: clockOuterCircle.height/2 - mouseY
        property real angle: Math.atan2(truex, truey)
        property real strictangle: parseInt(angle * 180 / Math.PI)
        property real modulo: strictangle % 6
        property int seconds_up_flag: 0
        property int seconds_down_flag: 0
        property int minutes_up_flag: 0
        property int minutes_down_flag: 0
        property int temp_seconds: 0
        property int temp_minutes: 0
        
        enabled: !inProgressFlag
        anchors.fill: parent
        preventStealing: true

        onPositionChanged: if (timerbackmousearea.angle < 0) {
                               timerHand.rotationAngle = strictangle - modulo + 360;
                               timerValue = parseInt(timerHand.rotationAngle/6);

                               if (secondsFlag) {
                                   seconds = timerValue;

                                   // FIXME: This whole code section below should be implemented in a more logical fashion.
                                   if (seconds == 0) {
                                       if (temp_seconds - seconds > 58) {
                                           // increasing minutes
                                           seconds_up_flag = 1
                                           temp_seconds = 0
                                       }
                                       else if (temp_seconds - seconds > 0) {
                                           // decreasing minutes
                                           seconds_down_flag = 1
                                           temp_seconds = 0
                                       }
                                       else {}

                                       if (seconds_up_flag == 1) {
                                           if (minutes == 59) {
                                               hours += 1
                                               minutes = 0
                                           }
                                           else {
                                               minutes += 1
                                           }
                                           seconds_up_flag = 0;
                                       }
                                   }

                                   if (seconds == 1) {
                                       temp_seconds = seconds
                                   }

                                   if (seconds == 59) {
                                       temp_seconds = seconds
                                       if (seconds_down_flag == 1) {
                                           if (minutes == 0) {
                                               minutes = 59
                                               hours -= 1
                                           }
                                           else {
                                               minutes -= 1
                                           }
                                           seconds_down_flag = 0;
                                       }
                                   }


                               }

                               if (minutesFlag) {
                                   minutes = timerValue;

                                   if (minutes == 0) {
                                       if (temp_minutes - minutes > 58) {
                                           // increasing hours
                                           minutes_up_flag = 1
                                           temp_minutes = 0
                                       }
                                       else if (temp_minutes - minutes > 0) {
                                           // decreasing hours
                                           minutes_down_flag = 1
                                           temp_minutes = 0
                                       }
                                       else {}

                                       if (minutes_up_flag == 1 && hours != 59) {
                                           hours += 1
                                           minutes_up_flag = 0;
                                       }
                                   }

                                   if (minutes == 1) {
                                       temp_minutes = minutes
                                   }

                                   if (minutes == 59) {
                                       temp_minutes = minutes
                                       if (minutes_down_flag == 1 && hours != 0) {
                                           hours -= 1
                                           minutes_down_flag = 0;
                                       }
                                   }
                               }

                               if (hoursFlag) {
                                   hours = timerValue;
                               }
                           }
                           else {
                               timerHand.rotationAngle = strictangle - modulo + 6;
                               timerValue = parseInt(timerHand.rotationAngle/6);

                               if (secondsFlag) {
                                   seconds = timerValue;

                                   if (seconds == 0) {
                                       if (temp_seconds - seconds > 58) {
                                           // increasing minutes
                                           seconds_up_flag = 1
                                           temp_seconds = 0
                                       }
                                       else if (temp_seconds - seconds > 0) {
                                           // decreasing minutes
                                           seconds_down_flag = 1
                                           temp_seconds = 0
                                       }
                                       else {}

                                       if (seconds_up_flag == 1) {
                                           if (minutes == 59) {
                                               hours += 1
                                               minutes = 0
                                           }
                                           else {
                                               minutes += 1
                                           }
                                           seconds_up_flag = 0;
                                       }
                                   }

                                   if (seconds == 1) {
                                       temp_seconds = seconds
                                   }

                                   if (seconds == 59) {
                                       temp_seconds = seconds
                                       if (seconds_down_flag == 1) {
                                           if (minutes == 0) {
                                               minutes = 59
                                               hours -= 1
                                           }
                                           else {
                                               minutes -= 1
                                           }
                                           seconds_down_flag = 0;
                                       }
                                   }


                               }

                               if (minutesFlag) {
                                   minutes = timerValue;

                                   if (minutes == 0) {
                                       if (temp_minutes - minutes > 58) {
                                           // increasing hours
                                           minutes_up_flag = 1
                                           temp_minutes = 0
                                       }
                                       else if (temp_minutes - minutes > 0) {
                                           // decreasing hours
                                           minutes_down_flag = 1
                                           temp_minutes = 0
                                       }
                                       else {}

                                       if (minutes_up_flag == 1 && hours != 59) {
                                           hours += 1
                                           minutes_up_flag = 0;
                                       }
                                   }

                                   if (minutes == 1) {
                                       temp_minutes = minutes
                                   }

                                   if (minutes == 59) {
                                       temp_minutes = minutes
                                       if (minutes_down_flag == 1 && hours != 0) {
                                           hours -= 1
                                           minutes_down_flag = 0;
                                       }
                                   }
                               }

                               if (hoursFlag) {
                                   hours = timerValue;
                               }
                           }
    }
}

